Skip to content
This repository was archived by the owner on Jul 15, 2026. It is now read-only.

Commit 0b80ace

Browse files
author
Mark Brettell
committed
tidying
1 parent 8a11dfc commit 0b80ace

2 files changed

Lines changed: 2 additions & 3 deletions

File tree

core/include/traccc/gbts_seeding/gbts_seeding_config.hpp

Lines changed: 1 addition & 1 deletion
Original file line numberDiff line numberDiff line change
@@ -114,7 +114,7 @@ struct gbts_seed_extraction_params {
114114
// controls if seeds of shorter lengths
115115
// can win bidding against longer seeds
116116
float add_hit = 14.0f;
117-
// m_J is stored in 30 + 1 bits
117+
// seed quality is an int scaled up from a float
118118
// max qual = add_hit*max_length*qual_scale
119119
float qual_scale =
120120
0.01f * static_cast<float>(INT_MAX) /

device/cuda/src/gbts_seeding/kernels/GbtsGraphProcessingKernels.cuh

Lines changed: 1 addition & 2 deletions
Original file line numberDiff line numberDiff line change
@@ -286,7 +286,7 @@ void __global__ fill_path_store(int2* d_path_store, int* d_output_graph,
286286
}
287287
path_idx = atomicAdd(&d_counters[7], 1);
288288
if (path_idx >= nPaths) {
289-
break;
289+
break;
290290
}
291291
int live_idx = atomicAdd(&n_live_paths, 1);
292292
if (live_idx >= traccc::device::gbts_consts::live_path_buffer) {
@@ -699,7 +699,6 @@ void __global__ gbts_seed_conversion_kernel(
699699
const unsigned int nProps, const unsigned int max_num_neighbours) {
700700

701701
int edge_size = 2 + 1 + max_num_neighbours;
702-
703702
edm::seed_collection::device seeds_device(output_seeds);
704703
for (int prop_idx = threadIdx.x + blockIdx.x * blockDim.x;
705704
prop_idx < nProps; prop_idx += blockDim.x * gridDim.x) {

0 commit comments

Comments
 (0)